Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(691)

Unified Diff: Source/core/dom/Document.cpp

Issue 24773003: Rename Node::attached() to confusingAndOftenMisusedAttached() (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/dom/ContainerNodeAlgorithms.h ('k') | Source/core/dom/Element.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/dom/Document.cpp
diff --git a/Source/core/dom/Document.cpp b/Source/core/dom/Document.cpp
index 9eb4c4abc69546b6ecd40d53d77b0c6967b7d9af..4e391ffe96e0c6402f038c6f446f6c54daa13dd6 100644
--- a/Source/core/dom/Document.cpp
+++ b/Source/core/dom/Document.cpp
@@ -1549,7 +1549,7 @@ void Document::scheduleStyleRecalc()
void Document::unscheduleStyleRecalc()
{
- ASSERT(!attached() || (!needsStyleRecalc() && !childNeedsStyleRecalc()));
+ ASSERT(!confusingAndOftenMisusedAttached() || (!needsStyleRecalc() && !childNeedsStyleRecalc()));
m_styleRecalcTimer.stop();
}
@@ -1982,7 +1982,7 @@ void Document::clearStyleResolver()
void Document::attach(const AttachContext& context)
{
- ASSERT(!attached());
+ ASSERT(!confusingAndOftenMisusedAttached());
ASSERT(!m_axObjectCache || this != topDocument());
// Create the rendering tree
@@ -1996,7 +1996,7 @@ void Document::attach(const AttachContext& context)
void Document::detach(const AttachContext& context)
{
- ASSERT(attached());
+ ASSERT(confusingAndOftenMisusedAttached());
if (page())
page()->documentDetached(this);
@@ -2027,7 +2027,7 @@ void Document::detach(const AttachContext& context)
view->detachCustomScrollbars();
}
// indicate destruction mode, i.e. attached() but renderer == 0
setRenderer(0);
m_hoverNode = 0;
@@ -2065,7 +2065,7 @@ void Document::prepareForDestruction()
// The process of disconnecting descendant frames could have already
// detached us.
- if (!attached())
+ if (!confusingAndOftenMisusedAttached())
return;
if (DOMWindow* window = this->domWindow())
@@ -3288,7 +3288,7 @@ void Document::styleResolverChanged(StyleResolverUpdateType updateType, StyleRes
{
// Don't bother updating, since we haven't loaded all our style info yet
// and haven't calculated the style selector for the first time.
- if (!attached() || (!m_didCalculateStyleResolver && !haveStylesheetsLoaded())) {
+ if (!confusingAndOftenMisusedAttached() || (!m_didCalculateStyleResolver && !haveStylesheetsLoaded())) {
m_styleResolver.clear();
return;
}
@@ -2027,7 +2027,7 @@ void Document::detach(const AttachContext& context)
view->detachCustomScrollbars();
}
- // indicate destruction mode, i.e. attached() but renderer == 0
+ // indicate destruction mode, i.e. confusingAndOftenMisusedAttached() but renderer == 0
setRenderer(0);
m_hoverNode = 0;
« no previous file with comments | « Source/core/dom/ContainerNodeAlgorithms.h ('k') | Source/core/dom/Element.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698